@@ -10,6 +10,7 @@ BEGIN {
                 BLOCK_SIZE TAR_PAD TAR_END ON_UNIX BLOCK CAN_READLINK MAGIC 
                 VERSION UNAME GNAME CAN_CHOWN MODE CHECK_SUM UID GID NAME_LENGTH
                 GZIP_MAGIC_NUM MODE_READ LONGLINK LONGLINK_NAME PREFIX_LENGTH
+                LABEL
             ];
 
     require Time::Local if $^O eq "MacOS";
@@ -25,6 +26,7 @@ use constant FIFO           => 6;
 use constant SOCKET         => 8;
 use constant UNKNOWN        => 9;
 use constant LONGLINK       => 'L';
+use constant LABEL          => 'V';
 
 use constant BUFFER         => 4096;
 use constant HEAD           => 512;
